aboutsummaryrefslogtreecommitdiffstats
path: root/libgnomecanvas/gnome-canvas-widget.h
diff options
context:
space:
mode:
Diffstat (limited to 'libgnomecanvas/gnome-canvas-widget.h')
-rw-r--r--libgnomecanvas/gnome-canvas-widget.h23
1 files changed, 8 insertions, 15 deletions
diff --git a/libgnomecanvas/gnome-canvas-widget.h b/libgnomecanvas/gnome-canvas-widget.h
index f7517c3832..32514aad6e 100644
--- a/libgnomecanvas/gnome-canvas-widget.h
+++ b/libgnomecanvas/gnome-canvas-widget.h
@@ -34,23 +34,20 @@
#ifndef GNOME_CANVAS_WIDGET_H
#define GNOME_CANVAS_WIDGET_H
-
#include <libgnomecanvas/gnome-canvas.h>
-
G_BEGIN_DECLS
-
/* Widget item for canvas. The widget is positioned with respect to an anchor point.
* The following object arguments are available:
*
* name type read/write description
* ------------------------------------------------------------------------------------------
* widget GtkWidget* RW Pointer to the widget
* x double RW X coordinate of anchor point
* y double RW Y coordinate of anchor point
* width double RW Width of widget (see below)
* height double RW Height of widget (see below)
* anchor GtkAnchorType RW Anchor side for widget
* size_pixels boolean RW Specifies whether the widget size
* is specified in pixels or canvas units.
@@ -59,7 +56,6 @@ G_BEGIN_DECLS
* Otherwise, it will be scaled.
*/
-
#define GNOME_TYPE_CANVAS_WIDGET (gnome_canvas_widget_get_type ())
#define GNOME_CANVAS_WIDGET(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GNOME_TYPE_CANVAS_WIDGET, GnomeCanvasWidget))
#define GNOME_CANVAS_WIDGET_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GNOME_TYPE_CANVAS_WIDGET, GnomeCanvasWidgetClass))
@@ -67,7 +63,6 @@ G_BEGIN_DECLS
#define GNOME_IS_CANVAS_WIDGET_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GNOME_TYPE_CANVAS_WIDGET))
#define GNOME_CANVAS_WIDGET_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GNOME_TYPE_CANVAS_WIDGET, GnomeCanvasWidgetClass))
-
typedef struct _GnomeCanvasWidget GnomeCanvasWidget;
typedef struct _GnomeCanvasWidgetClass GnomeCanvasWidgetClass;
@@ -76,12 +71,12 @@ struct _GnomeCanvasWidget {
GtkWidget *widget; /* The child widget */
- double x, y; /* Position at anchor */
- double width, height; /* Dimensions of widget */
+ gdouble x, y; /* Position at anchor */
+ gdouble width, height; /* Dimensions of widget */
GtkAnchorType anchor; /* Anchor side for widget */
- int cx, cy; /* Top-left canvas coordinates for widget */
- int cwidth, cheight; /* Size of widget in pixels */
+ gint cx, cy; /* Top-left canvas coordinates for widget */
+ gint cwidth, cheight; /* Size of widget in pixels */
guint destroy_id; /* Signal connection id for destruction of child widget */
@@ -93,11 +88,9 @@ struct _GnomeCanvasWidgetClass {
GnomeCanvasItemClass parent_class;
};
-
/* Standard Gtk function */
GType gnome_canvas_widget_get_type (void) G_GNUC_CONST;
-
G_END_DECLS
#endif
@@ -34,23 +34,20 @@
* ------------------------------------------------------------------------------------------
* widget GtkWidget* RW Pointer to the widget
- * x double RW X coordinate of anchor point
- * y double RW Y coordinate of anchor point
- * width double RW Width of widget (see below)
- * height double RW Height of widget (see below)
+ * x gdouble RW X coordinate of anchor point
+ * y gdouble RW Y coordinate of anchor point
+ * width gdouble RW Width of widget (see below)
+ * height gdouble RW Height of widget (see below)
* anchor GtkAnchorType RW Anchor side for widget
* size_pixels boolean RW Specifies whether the widget size